@@ -135,6 +135,14 @@ def compare_dates(component, target, comparator, operator):
     else:
         return operator(get_date_component(component, target), get_date_component(component, comparator))
 
+def apply_regex(regex: str, val: str):
+    result = re.findall(regex, val)
+    if result:
+        return result[0]
+    else:
+        return None
+
+vectorized_apply_regex = np.vectorize(apply_regex)
 vectorized_is_complete_date = np.vectorize(is_complete_date)
 vectorized_compare_dates = np.vectorize(compare_dates)
 vectorized_is_valid = np.vectorize(is_valid_date)
